/* clear_colormap - screen clearing program
**
** Copyright (C) 1993 by Jef Poskanzer <jef@netcom.com>.
**
** Permission to use, copy, modify, and distribute this software and its
** documentation for any purpose and without fee is hereby granted, provided
** that the above copyright notice appear in all copies and that both that
** copyright notice and this permission notice appear in supporting
** documentation.  This software is provided "as is" without express or
** implied warranty.
*/

#include <stdio.h>
#include <string.h>
#include <sys/types.h>
#include <raster.h>
#include <errno.h>
#include <sys/file.h>
#include <sys/time.h>

#define max(a,b) ( ((int)(a)) > ((int)(b)) ? (a) : (b) )

/* Forward routines. */
static void usage();

/* Globals. */
static char* argv0;

void
main( argc, argv )
int argc;
char* argv[];
    {
    int argn;
    int noclear;
    char* fb_name;
    struct raster* fb;
    struct raster_colormap* cm;

    argv0 = *argv;

    /* Parse flags. */
    argn = 1;
    noclear = 0;
    fb_name = (char*) 0;
    while ( argn < argc && argv[argn][0] == '-' && argv[argn][0] != '\0' )
	{
	if ( strncmp(argv[argn],"-noclear",max(strlen(argv[argn]),2)) == 0 )
	    noclear = 1;
	else if ( strncmp(argv[argn],"-fb",max(strlen(argv[argn]),2)) == 0 )
	    {
	    ++argn;
	    if ( argn >= argc )
		usage();
	    fb_name = argv[argn];
	    }
	else
	    usage();
	++argn;
	}
    
    if ( argn != argc )
	usage();

    /* Open framebuffer. */
    if ( fb_name == (char*) 0 )
	{
	fb = raster_coloropen();
	if ( fb == (struct raster*) 0 )
	    {
	    (void) fprintf(
		stderr, "%s: can't open color framebuffer\n", argv0 );
	    exit( 1 );
	    }
	}
    else
	{
	fb = raster_open( fb_name == (char*) 0 ? "/dev/fb" : fb_name );
	if ( fb == (struct raster*) 0 )
	    {
	    (void) fprintf(
		stderr, "%s: can't open framebuffer %s\n", argv0, fb_name );
	    exit( 1 );
	    }
	}
    
    cm = raster_colormap_get( fb );
    if ( cm == (struct raster_colormap*) 0 )
	{
	(void) fprintf( stderr, "%s: problem getting colormap\n", argv0 );
	exit( 1 );
	}

    cm->red[cm->ind] = cm->grn[cm->ind] = cm->blu[cm->ind] = 255;
    cm->red[cm->ind+1] = cm->grn[cm->ind+1] = cm->blu[cm->ind+1] = 0;
    cm->red[cm->ind+cm->len-1] = cm->grn[cm->ind+cm->len-1] =
	cm->blu[cm->ind+cm->len-1] = 0;

    (void) raster_colormap_set( fb, cm );

    if ( ! noclear )
	(void) raster_op( fb, 0, 0, fb->width, fb->height, RAS_CLEAR, 0, 0, 0 );

    raster_free( fb );
    exit( 0 );
    }

static void
usage()
    {
    char* use = "usage:  %s [-noclear] [-fb <framebuffer>]\n";

    (void) fprintf( stderr, use, argv0 );
    exit( 1 );
    }
